@@ -256,6 +256,11 @@
 \\put-adjacent
 \\pushToTag
 \\pt
+\\propertyUnset
+\\propertyTweak
+\\propertySet
+\\propertyRevert
+\\propertyOverride
 \\property-recursive
 \\printPartCombineTexts
 \\printKeyCancellation
@@ -552,6 +557,7 @@
 \\explicitClefVisibility
 \\expandFullBarRests
 \\eventChords
+\\etc
 \\espressivo
 \\epsfile
 \\episemInitium
